@@ -174,18 +174,20 @@ class CEA_Obj(object):
 
     def __init__(self, propName='', oxName='', fuelName='', fac_CR=None,
         useFastLookup=0, # depricated
-        makeOutput=0):
+        makeOutput=0, make_debug_prints=False):
         """
         #: Create the base CEA wrapper object.
         #: Fast Lookup is depricated.
         #: fac_CR = Contraction Ratio of finite area combustor (None=infinite)
+        #: if make_debug_prints is True, print debugging info to terminal.
         """
 
         self.makeOutput = makeOutput # makes "f.out"
+        self.make_debug_prints = make_debug_prints
         
         if fac_CR is not None:
             self.fac_CR = float( fac_CR )
-            print('Creating CEA_Obj with finite area combustor CR = ', self.fac_CR)
+            #print('Creating CEA_Obj with finite area combustor CR = ', self.fac_CR)
         else:
             self.fac_CR = None
 
@@ -209,13 +211,16 @@ class CEA_Obj(object):
 
         if oxName[-3:]=='(G)':
             oxName = 'G' + oxName[:-3]
-            print('Ox name changed to',oxName)
+            if self.make_debug_prints:
+                print('Ox name changed to',oxName)
         if fuelName[-3:]=='(G)':
             fuelName = 'G' + fuelName[:-3]
-            print('Fuel name changed to',fuelName)
+            if self.make_debug_prints:
+                print('Fuel name changed to',fuelName)
         if propName[-3:]=='(G)':
             propName = 'G' + propName[:-3]
-            print('Propellant name changed to',propName)
+            if self.make_debug_prints:
+                print('Propellant name changed to',propName)
 
         # may want to interpolate tables of CEA runs for speed
         self.useFastLookup = useFastLookup
@@ -247,13 +252,14 @@ class CEA_Obj(object):
 
                 self.cea_deck.append( propList )
                 self.desc += ' ' + propName
-                print("fuel Cards converted into prop Cards")
-                for card in self.cea_deck:
-                    if type(card) == type(''):
-                        print(card)
-                    else:
-                        for c in card:
-                            print(c)
+                if self.make_debug_prints:
+                    print("fuel Cards converted into prop Cards")
+                    for card in self.cea_deck:
+                        if type(card) == type(''):
+                            print(card)
+                        else:
+                            for c in card:
+                                print(c)
             elif propName in oxCards:
                 tempList = oxCards[ propName ]
                 if type(tempList) == type(''):
@@ -265,13 +271,14 @@ class CEA_Obj(object):
 
                 self.cea_deck.append( propList )
                 self.desc += ' ' + propName
-                print("ox Cards converted into prop Cards")
-                for card in self.cea_deck:
-                    if type(card) == type(''):
-                        print(card)
-                    else:
-                        for c in card:
-                            print(c)
+                if self.make_debug_prints:
+                    print("ox Cards converted into prop Cards")
+                    for card in self.cea_deck:
+                        if type(card) == type(''):
+                            print(card)
+                        else:
+                            for c in card:
+                                print(c)
             else:
                 print('ERROR... bad propellant name (%s) in cea_obj.py'%propName)
 
@@ -542,8 +549,9 @@ class CEA_Obj(object):
                 _PrintCountDict[self.desc] = 1
 
 
-        if self.makeOutput:
-            print("NOTICE... making an output file")
+        if self.make_debug_prints:
+            if self.makeOutput:
+                print("NOTICE... making an output file")
 
         # Before calling CEA, init values to zero so bad run can be detected
         py_cea.rockt.vaci[ self.i_thrt ] =  0.0 # Vacuum Isp at throat
@@ -913,7 +921,7 @@ class CEA_Obj(object):
             PcOvPe = PcOvPe * py_cea.rockt.app[ self.i_chm ]
         return PcOvPe
 
-    def get_MachNumber(self, Pc=100.0, MR=1.0,eps=40.0):
+    def get_MachNumber(self, Pc=100.0, MR=1.0, eps=40.0):
         """::
 
         #: return nozzle exit mach number.
@@ -925,6 +933,30 @@ class CEA_Obj(object):
         M = py_cea.rockt.vmoc[ self.i_exit ]
         return M
 
+    def get_Chamber_MachNumber(self, Pc=100.0, MR=1.0, fac_CR=None):
+        """::
+
+        #: Return  mach numbers at the chamber
+        #: Pc = combustion end pressure (psia)
+        #: MR is only used for ox/fuel combos.
+        #: fac_CR = Contraction Ratio of finite area combustor, (None=infinite)
+        """
+        # Allow user to override fac_CR from CEA_Obj __init__
+        save_fac_CR = self.fac_CR
+        if fac_CR is not None:
+            self.fac_CR = fac_CR
+            
+        if self.fac_CR is None:
+            print('ERROR in get_Chamber_MachNumber... Need value for fac_CR')
+            raise Exception('ERROR in get_Chamber_MachNumber... Need value for fac_CR')
+            
+        self.setupCards( Pc=Pc, MR=MR )
+
+        self.fac_CR = save_fac_CR   # restore fac_CR
+        
+        M = py_cea.rockt.vmoc[ 1 ]
+        return M
+
     def get_Temperatures(self, Pc=100.0, MR=1.0,eps=40.0, frozen=0, frozenAtThroat=0):
         """::
 
@@ -941,7 +973,11 @@ class CEA_Obj(object):
         
         # convert from Kelvin to Rankine
         #tempList = 1.8 * py_cea.prtout.ttt[:3]
-        tempList = list( py_cea.prtout.ttt[:3] )
+        if self.fac_CR is not None:
+            tempList = list( py_cea.prtout.ttt[1:4] )
+        else:
+            tempList = list( py_cea.prtout.ttt[:3] )
+            
         tempList = [1.8*T for T in tempList]
         return tempList # Tc, Tthroat, Texit
 
@@ -976,6 +1012,25 @@ class CEA_Obj(object):
         return sonicList[ 0 ] # 0 == self.i_chm here
 
 
+    def get_Entropies(self, Pc=100.0, MR=1.0,eps=40.0):
+        """::
+
+        #: Return a list of entropies at the chamber, throat and exit CAL/(G)(K)
+        #: Pc = combustion end pressure (psia)
+        #: MR is only used for ox/fuel combos.
+        #: eps = Nozzle Expansion Area Ratio
+        """
+        self.setupCards( Pc=Pc, MR=MR, eps=eps)
+        
+        if self.fac_CR is not None:
+            sList =  list(py_cea.prtout.ssum[1:4])
+        else:
+            sList =  list(py_cea.prtout.ssum[:3])
+        
+        for i,s in enumerate( sList ):
+            sList[i] = s * 8314.51 / 4184.0  # convert into CAL/(G)(K)
+        return sList
+
     def get_Enthalpies(self, Pc=100.0, MR=1.0,eps=40.0):
         """::
 
@@ -995,7 +1050,8 @@ class CEA_Obj(object):
             hList[i] = h * 1.8 * 8314.51 / 4184.0  # convert into BTU/lbm
         return hList
 
-    def get_SpeciesMassFractions(self, Pc=100.0, MR=1.0,eps=40.0, frozen=0, frozenAtThroat=0):
+    def get_SpeciesMassFractions(self, Pc=100.0, MR=1.0,eps=40.0, 
+                                 frozen=0, frozenAtThroat=0, min_fraction=0.000005):
         """::
 
         #: Returns species mass fractions at the injector face, chamber, throat and exit.
@@ -1006,7 +1062,7 @@ class CEA_Obj(object):
         #: frozenAtThroat flag, 0=frozen in chamber, 1=frozen at throat
         #: Returns 2 dictionaries
         #: molWtD dictionary: index=species: value=molecular weight
-        #: massFracD dictionary: index=species: value=[massfrac_chm, massfrac_tht, massfrac_exit]
+        #: massFracD dictionary: index=species: value=[massfrac_injface, massfrac_chm, massfrac_tht, massfrac_exit]
         """
 
         self.setupCards( Pc=Pc, MR=MR, eps=eps, frozen=frozen, frozenAtThroat=frozenAtThroat)
@@ -1027,7 +1083,7 @@ class CEA_Obj(object):
                     mw = py_cea.therm.mw[k-1]
                     
                     mfL.append( en*mw )
-                    if mfL[-1] >= 0.000005:
+                    if mfL[-1] >= min_fraction: # default = 0.000005
                         gt_zero = True
                 
                 if gt_zero:
@@ -1042,7 +1098,8 @@ class CEA_Obj(object):
                     
         return molWtD, massFracD
 
-    def get_SpeciesMoleFractions(self, Pc=100.0, MR=1.0,eps=40.0, frozen=0, frozenAtThroat=0):
+    def get_SpeciesMoleFractions(self, Pc=100.0, MR=1.0,eps=40.0, 
+                                 frozen=0, frozenAtThroat=0, min_fraction=0.000005):
         """::
 
         #: Returns species mole fractions at the injector face, chamber, throat and exit.
@@ -1053,7 +1110,7 @@ class CEA_Obj(object):
         #: frozenAtThroat flag, 0=frozen in chamber, 1=frozen at throat
         #: Returns 2 dictionaries
         #: molWtD dictionary: index=species: value=molecular weight
-        #: moleFracD dictionary: index=species: value=[molefrac_chm, molefrac_tht, molefrac_exit]
+        #: moleFracD dictionary: index=species: value=[molefrac_injface, molefrac_chm, molefrac_tht, molefrac_exit]
         """
         
         self.setupCards( Pc=Pc, MR=MR, eps=eps, frozen=frozen, frozenAtThroat=frozenAtThroat)
@@ -1075,7 +1132,7 @@ class CEA_Obj(object):
                     mw = py_cea.therm.mw[k-1]
                     
                     mfL.append( en/totn )
-                    if mfL[-1] >= 0.000005:
+                    if mfL[-1] >= min_fraction: # default = 0.000005
                         gt_zero = True
                 
                 if gt_zero:
@@ -1110,7 +1167,7 @@ class CEA_Obj(object):
         #: eps = Nozzle Expansion Area Ratio
         """
         self.setupCards( Pc=Pc, MR=MR, eps=eps)
-        # convert from m/sec into ft/sec
+        
         if self.fac_CR is not None:
             dList =  list(py_cea.prtout.vlm[1:4])
         else:
